pub fn init_globals()Expand description
Initializes the vanilla registry and the behavior registries.
Idempotent, so an embedder loading several worlds in one process bootstraps once.
pub fn init_globals()Initializes the vanilla registry and the behavior registries.
Idempotent, so an embedder loading several worlds in one process bootstraps once.